Index: src/wp-includes/widgets.php
===================================================================
--- src/wp-includes/widgets.php	(revision 32685)
+++ src/wp-includes/widgets.php	(working copy)
@@ -687,8 +687,6 @@
 	'wp_widget_recent_comments_control'
 );
 
-/* Template tags & API functions */
-
 /**
  * Register a widget
  *
@@ -700,12 +698,12 @@
  *
  * @global WP_Widget_Factory $wp_widget_factory
  *
  * @param string $widget_class The name of a class that extends WP_Widget
  */
-function register_widget($widget_class) {
+function register_widget($widgetish) {
 	global $wp_widget_factory;
 
-	$wp_widget_factory->register($widget_class);
+	$wp_widget_factory->register($widgetish);
 }
 
 /**
@@ -720,12 +718,12 @@
  *
  * @global WP_Widget_Factory $wp_widget_factory
  *
  * @param string $widget_class The name of a class that extends WP_Widget
  */
-function unregister_widget($widget_class) {
+function unregister_widget($widgetish) {
 	global $wp_widget_factory;
 
-	$wp_widget_factory->unregister($widget_class);
+	$wp_widget_factory->unregister($widgetish);
 }
 
 /**
@@ -700,12 +698,12 @@
  * @global WP_Widget_Factory $wp_widget_factory
  *
- * @param string $widget_class The name of a class that extends WP_Widget
+ * @param string $widgetish The name of a class that extends WP_Widget or an instance of WP_Widget
  */
@@ -720,12 +718,12 @@
  * @global WP_Widget_Factory $wp_widget_factory
  *
- * @param string $widget_class The name of a class that extends WP_Widget
+ * @param string $widgetish The name of a class that extends WP_Widget or an instance of WP_Widget
  */
